@@ -99,8 +99,8 @@ typedef NvU8*              NVREGSTR;
  */
 #if (defined(NV_UNIX) || defined(vxworks) || defined(NV_WINDOWS_CE) ||  \
      defined(__arm) || defined(__IAR_SYSTEMS_ICC__) || defined(NV_QNX) || \
-     defined(NV_INTEGRITY) || defined(NV_MODS) || defined(__GNUC__) ||  \
-     defined(NV_MACINTOSH_64)) && \
+     defined(NV_INTEGRITY) || defined(NV_HOS) || defined(NV_MODS) || \
+     defined(__GNUC__) || defined(NV_MACINTOSH_64)) && \
     (!defined(NV_MACINTOSH) || defined(NV_MACINTOSH_64))
 typedef unsigned int       NvV32; /* "void": enumerated or multiple fields   */
 typedef unsigned int       NvU32; /* 0 to 4294967295                         */
@@ -227,7 +227,7 @@ typedef NvS8  S008;
 typedef NvS16 S016;
 typedef NvS32 S032;
 #endif
-#if defined(MACOS) || defined(macintosh) || defined(__APPLE_CC__) || defined(NV_MODS) || defined(MINIRM) || defined(NV_UNIX) || defined (NV_QNX) || defined(NV_INTEGRITY)
+#if defined(MACOS) || defined(macintosh) || defined(__APPLE_CC__) || defined(NV_MODS) || defined(MINIRM) || defined(NV_UNIX) || defined (NV_QNX) || defined(NV_INTEGRITY) || defined(NV_HOS)
 /* more obsolete stuff */
 /* need to provide these on macos9 and macosX */
 #if defined(__APPLE_CC__)  /* gross but Apple osX already claims ULONG */
@@ -279,7 +279,7 @@ typedef unsigned char *PUCHAR;
 #endif
 
 /* Aligns fields in structs  so they match up between 32 and 64 bit builds */
-#if defined(__GNUC__) || defined(NV_QNX)
+#if defined(__GNUC__) || defined(NV_QNX) || defined(NV_HOS)
 #define NV_ALIGN_BYTES(size) __attribute__ ((aligned (size)))
 #elif defined(__arm)
 #define NV_ALIGN_BYTES(size) __align(ALIGN)
@@ -295,7 +295,7 @@ typedef unsigned char *PUCHAR;
 // and NV_ALIGN_BYTES is required after the variable name.
 #if defined(NV_WINDOWS)
 #define NV_DECLARE_ALIGNED(TYPE_VAR, ALIGN) __declspec(align(ALIGN)) TYPE_VAR
-#elif defined(__GNUC__) || defined(NV_QNX)
+#elif defined(__GNUC__) || defined(NV_QNX) || defined(NV_HOS)
 #define NV_DECLARE_ALIGNED(TYPE_VAR, ALIGN) TYPE_VAR __attribute__ ((aligned (ALIGN)))
 #elif defined(__arm)
 #define NV_DECLARE_ALIGNED(TYPE_VAR, ALIGN) __align(ALIGN) TYPE_VAR
@@ -306,6 +306,13 @@ typedef unsigned char *PUCHAR;
 #define NVRM_IMPORT __declspec(dllimport)
 #else
 #define NVRM_IMPORT
+#endif
+
+// Check for typeof support. For now restricting to GNUC compilers.
+#if defined(__GNUC__)
+#define NV_TYPEOF_SUPPORTED 1
+#else
+#define NV_TYPEOF_SUPPORTED 0
 #endif
 
  /***************************************************************************\
@@ -428,6 +435,7 @@ typedef NvSFXP32                                                    NvSFXP31_1;
 typedef NvUFXP16                                                    NvUFXP0_16;
 typedef NvUFXP16                                                    NvUFXP4_12;
 typedef NvUFXP16                                                     NvUFXP8_8;
+typedef NvUFXP32                                                    NvUFXP4_28;
 typedef NvUFXP32                                                    NvUFXP8_24;
 typedef NvUFXP32                                                    NvUFXP9_23;
 typedef NvUFXP32                                                   NvUFXP10_22;
