@@ -31,8 +31,6 @@
 #include "nvkms.h"
 #include "nv-modeset-interface.h"
 
-#include "nv-retpoline.h"
-
 /*
  * This option decides if nvidia-modeset.ko will be built with support
  * for Linux or Linux 32-bit (FreeBSD/amd64) compatibility.  This
@@ -178,11 +176,6 @@ int NVKMS_API_CALL nvkms_copyout(NvU64 uaddr, const void *kptr, size_t n)
     return copyout(kptr, nvKmsNvU64ToPointer(uaddr), n);
 }
 
-void NVKMS_API_CALL nvkms_yield(void)
-{
-    pause("yield", 1 /* timeout in 1/hz units */);
-}
-
 int NVKMS_API_CALL nvkms_snprintf(char *str, size_t size, const char *format, ...)
 {
     int ret;
@@ -327,8 +320,7 @@ struct nvkms_timer_t {
     NvBool isRefPtr;
     NvBool callout_created;
     nvkms_timer_proc_t *proc;
-    void *dataPtr;
-    NvU32 dataU32;
+    void *data;
     LIST_ENTRY(nvkms_timer_t) timers_list;
 };
 
@@ -343,7 +335,7 @@ static struct {
 static void nvkms_taskqueue_callback(void *arg, int pending)
 {
     struct nvkms_timer_t *timer = arg;
-    void *dataPtr;
+    void *data;
 
     /*
      * We can delete this timer from pending timers list - it's being
@@ -368,16 +360,16 @@ static void nvkms_taskqueue_callback(void *arg, int pending)
     if (timer->isRefPtr) {
         // If the object this timer refers to was destroyed, treat the timer as
         // canceled.
-        dataPtr = nvkms_dec_ref(timer->dataPtr);
-        if (!dataPtr) {
+        data = nvkms_dec_ref(timer->data);
+        if (!data) {
             timer->cancel = NV_TRUE;
         }
     } else {
-        dataPtr = timer->dataPtr;
+        data = timer->data;
     }
 
     if (!timer->cancel) {
-        timer->proc(dataPtr, timer->dataU32);
+        timer->proc(data);
         timer->complete = NV_TRUE;
     }
 
@@ -398,15 +390,14 @@ static void nvkms_callout_callback(void *arg)
 
 static void
 nvkms_init_timer(struct nvkms_timer_t *timer, nvkms_timer_proc_t *proc,
-                 void *dataPtr, NvU32 dataU32, NvBool isRefPtr, NvU64 usec)
+                 void *arg, NvBool isRefPtr, NvU64 usec)
 {
     timer->cancel = NV_FALSE;
     timer->complete = NV_FALSE;
     timer->isRefPtr = isRefPtr;
 
     timer->proc = proc;
-    timer->dataPtr = dataPtr;
-    timer->dataU32 = dataU32;
+    timer->data = arg;
 
     TASK_INIT(&timer->task,
               0 /* priority */,
@@ -437,22 +428,20 @@ nvkms_init_timer(struct nvkms_timer_t *timer, nvkms_timer_proc_t *proc,
 }
 
 nvkms_timer_handle_t*
-NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc,
-                                 void *dataPtr, NvU32 dataU32,
+NVKMS_API_CALL nvkms_alloc_timer(nvkms_timer_proc_t *proc, void *arg,
                                  NvU64 usec)
 {
     // nvkms_alloc_timer cannot be called from an interrupt context.
     struct nvkms_timer_t *timer = nvkms_alloc(sizeof(*timer), NV_TRUE);
     if (timer) {
-        nvkms_init_timer(timer, proc, dataPtr, dataU32, NV_FALSE, usec);
+        nvkms_init_timer(timer, proc, arg, NV_FALSE, usec);
     }
     return timer;
 }
 
 NvBool NVKMS_API_CALL
 nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
-                               struct nvkms_ref_ptr *ref_ptr,
-                               NvU32 dataU32, NvU64 usec)
+                               struct nvkms_ref_ptr *ref_ptr, NvU64 usec)
 {
     // nvkms_alloc_timer_with_ref_ptr is called from an interrupt bottom half
     // handler.
@@ -463,7 +452,7 @@ nvkms_alloc_timer_with_ref_ptr(nvkms_timer_proc_t *proc,
         // Reference the ref_ptr to make sure that it doesn't get freed before
         // the timer fires.
         nvkms_inc_ref(ref_ptr);
-        nvkms_init_timer(timer, proc, ref_ptr, dataU32, NV_TRUE, usec);
+        nvkms_init_timer(timer, proc, ref_ptr, NV_TRUE, usec);
     }
 
     return timer != NULL;
@@ -568,11 +557,7 @@ void NVKMS_API_CALL nvkms_get_random(void *ptr, size_t size)
 
 #if NV_FGET_HAS_CAP_RIGHTS_T_ARG
   #include <sys/caprights.h>
-  #if __FreeBSD_version >= 1100012
-    #include <sys/capsicum.h>
-  #else
-    #include <sys/capability.h>
-  #endif
+  #include <sys/capability.h>
 #endif
 
 /*
@@ -667,63 +652,6 @@ void NVKMS_API_CALL nvkms_close_gpu(NvU32 gpuId)
     __rm_ops.close_gpu(gpuId, nvkms_nvidia_stack);
 }
 
-NvU32 NVKMS_API_CALL nvkms_enumerate_gpus(nv_gpu_info_t *gpu_info)
-{
-    return 0;
-}
-
-NvBool NVKMS_API_CALL nvkms_allow_write_combining(void)
-{
-    return __rm_ops.system_info.allow_write_combining;
-}
-
-/*************************************************************************
- * NVKMS interface for kernel space NVKMS clients like KAPI
- *************************************************************************/
-
-struct nvkms_per_open* NVKMS_API_CALL nvkms_open_from_kapi
-(
-    struct NvKmsKapiDevice *device
-)
-{
-    return NULL;
-}
-
-void NVKMS_API_CALL nvkms_close_from_kapi(struct nvkms_per_open *popen)
-{
-}
-
-NvBool NVKMS_API_CALL nvkms_ioctl_from_kapi
-(
-    struct nvkms_per_open *popen,
-    NvU32 cmd, void *params_address, const size_t params_size
-)
-{
-    return NV_FALSE;
-}
-
-
-/*************************************************************************
- * APIs for locking.
- *************************************************************************/
-
-nvkms_sema_handle_t* NVKMS_API_CALL nvkms_sema_alloc(void)
-{
-    return NULL;
-}
-
-void NVKMS_API_CALL nvkms_sema_free(nvkms_sema_handle_t *sema)
-{
-}
-
-void NVKMS_API_CALL nvkms_sema_down(nvkms_sema_handle_t *seam)
-{
-}
-
-void NVKMS_API_CALL nvkms_sema_up(nvkms_sema_handle_t *sema)
-{
-}
-
 /*************************************************************************
  * File operation callback functions.
  *************************************************************************/
@@ -750,7 +678,7 @@ static int nvkms_ioctl(
     u_long cmd,
     caddr_t data,
     int fflag,
-    struct thread *td
+    d_thread_t *td
 )
 {
     u_long nr, size;
@@ -780,6 +708,7 @@ static int nvkms_ioctl(
     sx_xlock(&nvkms_lock);
     ret = nvKmsIoctl(popen->data,
                      params->cmd,
+                     NVKMS_IOCTL_FROM_USER_SPACE,
                      params->address,
                      params->size);
     sx_xunlock(&nvkms_lock);
@@ -791,7 +720,7 @@ static int nvkms_open(
     struct cdev *dev,
     int oflags,
     int devtype,
-    struct thread *td
+    d_thread_t *td
 )
 {
     struct nvkms_per_open *popen;
@@ -807,7 +736,7 @@ static int nvkms_open(
     nvkms_module.client_counter += 1;
     sx_xunlock(&nvkms_module.lock);
 
-    popen = nvkms_alloc(sizeof(*popen), NV_TRUE);
+    popen = nvkms_alloc(sizeof(*popen), NV_FALSE);
     if (popen == NULL) {
         return ENOMEM;
     }
@@ -826,7 +755,7 @@ static int nvkms_open(
     mtx_init(&popen->events.lock, "nvkms-events-lock", NULL, 0);
 
     sx_xlock(&nvkms_lock);
-    popen->data = nvKmsOpen(curproc->p_pid, NVKMS_CLIENT_USER_SPACE, popen);
+    popen->data = nvKmsOpen(popen);
     sx_xunlock(&nvkms_lock);
 
     /*
@@ -839,7 +768,7 @@ static int nvkms_open(
 static int nvkms_poll(
     struct cdev *dev,
     int events,
-    struct thread *td
+    d_thread_t *td
 )
 {
     struct nvkms_per_open *popen;
@@ -1059,7 +988,7 @@ nvidia_modeset_loader(struct module *m, int what, void *arg)
                     /*  We've deactivated timer so we need to clean after it */
                     LIST_REMOVE(timer, timers_list);
                     if (timer->isRefPtr) {
-                        nvkms_dec_ref(timer->dataPtr);
+                        nvkms_dec_ref(timer->data);
                     }
                     nvkms_free(timer, sizeof(*timer));
                 }
