@@ -54,7 +54,7 @@ typedef struct {
  * #define an absolute maximum used as a sanity check for the
  * NV_ESC_IOCTL_XFER_CMD ioctl() size argument.
  */
-#define NV_ABSOLUTE_MAX_IOCTL_SIZE  8192
+#define NV_ABSOLUTE_MAX_IOCTL_SIZE  16384
 
 /*
  * Solaris provides no more than 8 bits for the argument size in
@@ -366,6 +366,7 @@ typedef struct gpuObject            *nvgpuObjectHandle_t;
 typedef struct gpuChannelInfo       *nvgpuChannelInfo_t;
 typedef struct gpuCaps              *nvgpuCaps_t;
 typedef struct gpuAllocInfo         *nvgpuAllocInfo_t;
+typedef struct gpuSurfaceMappingInfo *nvgpuSurfaceMapInfo_t;
 typedef struct gpuVaAllocInfo       *nvgpuVaAllocInfo_t;
 typedef struct gpuMapInfo           *nvgpuMapInfo_t;
 typedef struct gpuFbInfo            *nvgpuFbInfo_t;
@@ -373,6 +374,8 @@ typedef struct gpuFaultInfo         *nvgpuFaultInfo_t;
 typedef struct gpuInfo              *nvgpuInfo_t;
 typedef struct gpuPageLevelInfo     *nvgpuPageLevelInfo_t;
 typedef struct gpuChannelPhysInfo   *nvgpuChannelPhysInfo_t;
+typedef struct gpuChannelCtxBufferInfo *nvgpuChannelCtxBufferInfo_t;
+typedef struct gpuChannelBufferVa   *nvgpuChannelBufferVa_t;
 
 /*
  * flags
@@ -700,12 +703,16 @@ NV_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nvidia_stack_t *, nvgpuSessio
 NV_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nvidia_stack_t *, nvgpuSessionHandle_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *, unsigned long long, unsigned long long);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_dup_address_space(nvidia_stack_t *, nvgpuSessionHandle_t, NvU8*, NvHandle, NvHandle, nvgpuAddressSpaceHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_va(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuVaAllocInfo_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_pa(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
 
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
+
+NV_STATUS  NV_API_CALL  rm_gpu_ops_get_surface_map_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, nvgpuSurfaceMapInfo_t);
+
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **, NvU32);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void*);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, nvgpuChannelInfo_t);
@@ -724,13 +731,26 @@ NV_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nvidia_stack_t *, nvg
 NV_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nvidia_stack_t *, nvgpuChannelHandle_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_gmmu_fmt(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void **);
 NV_STATUS  NV_API_CALL rm_gpu_ops_dup_allocation(nvidia_stack_t *, NvHandle, nvgpuAddressSpaceHandle_t, NvU64, nvgpuAddressSpaceHandle_t, NvU64*, NvBool);
+
+NV_STATUS  NV_API_CALL  rm_gpu_ops_dup_memory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle hClientMem, NvHandle *hDupMemory);
+
 NV_STATUS  NV_API_CALL rm_gpu_ops_free_duped_handle(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle);
+NV_STATUS  NV_API_CALL rm_gpu_ops_check_pseudo_p9(nvidia_stack_t *sp, nvgpuAddressSpaceHandle_t vaspace, NvBool *isPseudoP9);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_fb_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFbInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_ids(nvidia_stack_t *sp, NvU8 *pUuid, unsigned uuidLength, NvU32 *pDeviceId, NvU32 *pSubdeviceId);
 NV_STATUS  NV_API_CALL rm_gpu_ops_init_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_page_level_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, nvgpuPageLevelInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_phys_info(nvidia_stack_t *, NvHandle, NvHandle, nvgpuChannelPhysInfo_t);
+void       NV_API_CALL rm_gpu_ops_free_channel_inst_ptr(nvidia_stack_t *, void*);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_set_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, unsigned, NvBool);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_unset_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_count(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU32 *);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, nvgpuChannelCtxBufferInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_ctx_buffer_phys_info(nvidia_stack_t *, void *, NvU64, NvU64 *);
+NV_STATUS  NV_API_CALL rm_gpu_ops_validate_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvHandle);
+NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, nvgpuChannelBufferVa_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_unbind_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvU32, NvU64*);
 
 void       NV_API_CALL rm_kernel_rmapi_op(nvidia_stack_t *sp, void *ops_cmd);
 
