@@ -188,6 +188,8 @@ int nvidia_suspend(device_t dev)
     sc = device_get_softc(dev);
     nv = sc->nv_state;
 
+    nvidia_modeset_suspend(nv->gpu_id);
+
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
     status = rm_power_management(sp, nv, 0, NV_PM_ACPI_STANDBY);
 
@@ -219,6 +221,11 @@ int nvidia_resume(device_t dev)
 
     NV_UMA_ZONE_FREE_STACK(sp);
 
+    if (status == NV_OK)
+    {
+        nvidia_modeset_resume(nv->gpu_id);
+    }
+
     return (status == NV_OK) ? 0 : EIO;
 }
 #endif /* NV_SUPPORT_ACPI_PM */
@@ -524,6 +531,25 @@ static int nv_dev_alloc_stacks(nvidia_softc_t *sc)
     return 0;
 }
 
+static nv_state_t *nvidia_find_state(NvU32 gpu_id)
+{
+    unsigned int i;
+    for (i = 0; i < NV_MAX_DEVICES; i++) {
+        nv_state_t *nv;
+        struct nvidia_softc *sc = devclass_get_softc(nvidia_devclass, i);
+        if (sc == NULL) {
+            continue;
+        }
+        nv = sc->nv_state;
+
+        if (nv->gpu_id == gpu_id) {
+            return nv;
+        }
+    }
+
+    return NULL;
+}
+
 int nvidia_open_dev(
     nv_state_t *nv,
     struct nvidia_filep *filep
@@ -590,6 +616,25 @@ failed:
     return status;
 }
 
+int nvidia_open_dev_kernel(
+    NvU32 gpu_id,
+    nvidia_stack_t *sp /* unused: nvidia_open_dev() will use its own stack */
+)
+{
+    int status;
+    nv_state_t *nv = nvidia_find_state(gpu_id);
+
+    if (nv == NULL) {
+        return EINVAL;
+    }
+
+    nv_lock_api(nv);
+    status = nvidia_open_dev(nv, NULL /* filep */);
+    nv_unlock_api(nv);
+
+    return status;
+}
+
 int nvidia_close_dev(
     nv_state_t *nv,
     struct nvidia_filep *filep
@@ -602,7 +647,9 @@ int nvidia_close_dev(
     sp = sc->sp[NV_DEV_STACK_API];
 
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
-    rm_free_unused_clients(sp, nv, filep);
+    if (filep != NULL) {
+        rm_free_unused_clients(sp, nv, filep);
+    }
 
     if (--sc->refcnt == 0) {
         if (sc->UD_object != NULL)
@@ -620,6 +667,21 @@ int nvidia_close_dev(
     return 0;
 }
 
+void nvidia_close_dev_kernel(
+    NvU32 gpu_id,
+    nvidia_stack_t *sp /* unused: nvidia_close_dev() will use its own stack */
+)
+{
+    nv_state_t *nv = nvidia_find_state(gpu_id);
+
+    if (nv == NULL) {
+        return;
+    }
+
+    nv_lock_api(nv);
+    nvidia_close_dev(nv, NULL /* filep */);
+    nv_unlock_api(nv);
+}
 
 int nvidia_modevent(
     module_t mod,
